@@ -6,14 +6,9 @@ developed by Daniel J. Bernstein.
 
 """
 
-import sys
+from __future__ import annotations
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final, Literal
-else:
-    from typing import Final, Literal
-
-from typing import Optional, Union, overload
+from typing import Final, Literal, Optional, Union, overload
 
 from mbedtls.exceptions import TLSError
 
