@@ -11,8 +11,7 @@ Encryption Algorithms"
 
 from __future__ import annotations
 
-import sys
-from typing import Optional
+from typing import Final, Optional, Protocol, runtime_checkable
 
 from mbedtls.cipher import (
     AES,
@@ -32,12 +31,6 @@ from mbedtls.cipher._cipher import (
     get_supported_ciphers as get_supported_ciphers,
 )
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final, Protocol
-else:
-    from typing import Final, Protocol
-
-
 # Add module-level aliases to comply with PEP 272.
 MODE_ECB: Final = Mode.ECB.value
 MODE_CBC: Final = Mode.CBC.value
@@ -51,6 +44,7 @@ MODE_XTS: Final = Mode.XTS.value
 MODE_CHACHAPOLY: Final = Mode.CHACHAPOLY.value
 
 
+@runtime_checkable
 class CipherType(Protocol):
     @property
     def __name__(self) -> str:
@@ -68,6 +62,7 @@ class CipherType(Protocol):
         ...
 
 
+@runtime_checkable
 class AEADCipherType(Protocol):
     @property
     def __name__(self) -> str:
