@@ -9,7 +9,8 @@ import os
 import socket as _pysocket
 import struct
 import sys
-from typing import Any, NoReturn, Optional, Tuple, Union, cast, overload
+from contextlib import suppress
+from typing import Any, Final, NoReturn, Optional, Tuple, Union, cast, overload
 
 from ._tls import HandshakeStep as HandshakeStep
 from ._tls import HelloVerifyRequest
@@ -35,11 +36,6 @@ from ._tlsi import ServerNameCallback as ServerNameCallback
 from ._tlsi import TLSConfiguration as TLSConfiguration
 from ._tlsi import TLSVersion as TLSVersion
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final
-else:
-    from typing import Final
-
 if sys.version_info < (3, 10):
     from typing_extensions import TypeAlias
 else:
@@ -403,6 +399,12 @@ class TLSWrappedSocket:
 
     def shutdown(self, how: int) -> None:
         self._buffer.shutdown()
+        # Alerts are much smaller but it doesn't matter.
+        close_notify = self._buffer.peek_outgoing(4096)
+        with suppress(OSError):
+            # Do not raise if the socket is already closed.
+            amt = self._socket.send(close_notify)
+            self._buffer.consume_outgoing(amt)
         self._socket.shutdown(how)
 
     # PEP 543 adds the following methods.
