@@ -4,9 +4,8 @@ from __future__ import annotations
 
 import datetime as dt
 import pickle
-import sys
 from pathlib import Path
-from typing import Any, Callable, Optional, Tuple, Union
+from typing import Any, Callable, Final, Optional, Tuple, Union
 
 import certifi
 import pytest
@@ -15,11 +14,6 @@ from mbedtls import hashlib
 from mbedtls.pk import ECC, RSA
 from mbedtls.x509 import CRL, CRT, CSR, BasicConstraints
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Final
-else:
-    from typing import Final
-
 _PEM = str
 _DER = bytes
 _PKey = Union[ECC, RSA]
@@ -154,11 +148,7 @@ class TestCertificate:
         assert isinstance(request.param, (CSR, CRT, CRL))
         return request.param
 
-    @pytest.mark.parametrize(
-        "repr_",
-        [repr, str],
-        ids=lambda f: f.__name__,  # type: ignore[no-any-return]
-    )
+    @pytest.mark.parametrize("repr_", [repr, str], ids=lambda f: f.__name__)
     def test_repr(
         self, repr_: Callable[[object], str], cert: Union[CSR, CRT, CRL]
     ) -> None:
